@@ -74,10 +74,17 @@ class ClientError(Exception):
             service_name=service_name,
             http_status_code=http_status_code,
             request_id=request_id)
+        msg = self.cleanup_error_msg(msg)
         super(ClientError, self).__init__(msg)
         self.http_status_code = http_status_code
         self.response = error_response
 
+    def cleanup_error_msg(self, msg):
+        msg = msg.replace('&quot;', '"').replace("&#39;", "'")\
+            .replace("/&lt;", "<").replace("&gt;", ">")
+
+        return msg
+
 
 class UnseekableStreamError(CdpCLIError):
     """
